@@ -153,9 +153,9 @@ set_attr(struct coda_vattr *attr, const dav_node *node);
 /*==================*/
 
 void
-dav_coda_loop(int device, size_t bufsize, time_t idle_time,
-              dav_is_mounted_fn is_mounted, volatile int *keep_on_running,
-              int dbg)
+dav_coda_loop(int device, char *mpoint, size_t bufsize, time_t idle_time,
+                   dav_is_mounted_fn is_mounted,
+                   volatile int *keep_on_running, int dbg)
 {
     debug = dbg;
     if (debug)
@@ -695,7 +695,7 @@ coda_statfs(void)
     }
 
     out->stat.f_blocks = st->blocks;
-    out->stat.f_bfree = st->bfree;
+    out->stat.f_bfree = st->bavail;
     out->stat.f_bavail = st->bavail;
     out->stat.f_files = st->files;
     out->stat.f_ffree = st->ffree;
