@@ -780,9 +780,15 @@ dav_get_file(const char *path, const char *cache_path, off_t *size,
 
     if (rd_uri) {
         rd_sess = create_rd_session(rd_uri);
+        char *rd_path = NULL;
+        if (rd_uri->query) {
+            rd_path = ne_concat(rd_uri->path, "?", rd_uri->query, NULL);
+        } else {
+            rd_path = ne_strdup(rd_uri->path);
+        }
 
         ne_request_destroy(req);
-        req = ne_request_create(rd_sess, "GET", rd_uri->path);
+        req = ne_request_create(rd_sess, "GET", rd_path);
 
         if (etag && *etag)
             ne_add_request_header(req, "If-None-Match", *etag);
@@ -799,6 +805,7 @@ dav_get_file(const char *path, const char *cache_path, off_t *size,
         if (use_compression)
             ne_decompress_destroy(dc_state);
         ret = get_error(ret, "GET", rd_sess);
+        free(rd_path);
     } else {
         ret = get_error(ret, "GET", session);
     }
@@ -1730,14 +1737,10 @@ file_reader(void *userdata, const char *block, size_t length)
    When a cookie with the same name as an already stored cookie, but with
    a different value is received, it's value is updated if necessary.
    Only n_cookies cookies will be stored. If the server sends more
-   different cookies these will be ignored.
-   status must be of class 2XX or 3XX, otherwise the cookie is ignored. */
+   different cookies these will be ignored. */
 static void
 get_cookies(ne_request *req, void *userdata, const ne_status *status)
 {
-    if (status->klass != 2 && status->klass != 3)
-        return;
-
     const char *cookie_hdr = ne_get_response_header(req, "Set-Cookie");
     if (!cookie_hdr)
         return;
@@ -1760,14 +1763,13 @@ get_cookies(ne_request *req, void *userdata, const ne_status *status)
         while (end > start && *(end - 1) == ' ')
             end--;
 
-        if ((start + 4) > end || *start == '=' || *(end - 1) == '=')
-            continue;
-
         char *es = strchr(start, '=');
         if (!es)
             continue;
         size_t nl = es - start;
         size_t vl = end - es - 1;
+        if (nl == 0 || vl == 0)
+            continue;
 
         int i = 0;
         for (i = 0; i < n_cookies; i++) {
